package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.system.mapper.FcryMapper;
import com.ruoyi.system.domain.Fcry;
import com.ruoyi.system.service.IFcryService;

/**
 * 方舱人员Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@Service
public class FcryServiceImpl implements IFcryService 
{
    @Autowired
    private FcryMapper fcryMapper;

    /**
     * 查询方舱人员
     * 
     * @param id 方舱人员主键
     * @return 方舱人员
     */
    @Override
    public Fcry selectFcryById(Long id)
    {
        return fcryMapper.selectFcryById(id);
    }

    /**
     * 查询方舱人员列表
     * 
     * @param fcry 方舱人员
     * @return 方舱人员
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Fcry> selectFcryList(Fcry fcry)
    {
        return fcryMapper.selectFcryList(fcry);
    }

    /**
     * 新增方舱人员
     * 
     * @param fcry 方舱人员
     * @return 结果
     */
    @Override
    public int insertFcry(Fcry fcry)
    {
        fcry.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        fcry.setCreateTime(DateUtils.getNowDate());
        return fcryMapper.insertFcry(fcry);
    }

    /**
     * 修改方舱人员
     * 
     * @param fcry 方舱人员
     * @return 结果
     */
    @Override
    public int updateFcry(Fcry fcry)
    {
        fcry.setUpdateTime(DateUtils.getNowDate());
        return fcryMapper.updateFcry(fcry);
    }

    /**
     * 批量删除方舱人员
     * 
     * @param ids 需要删除的方舱人员主键
     * @return 结果
     */
    @Override
    public int deleteFcryByIds(Long[] ids)
    {
        return fcryMapper.deleteFcryByIds(ids);
    }

    /**
     * 删除方舱人员信息
     * 
     * @param id 方舱人员主键
     * @return 结果
     */
    @Override
    public int deleteFcryById(Long id)
    {
        return fcryMapper.deleteFcryById(id);
    }
}
