package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.system.mapper.GldryMapper;
import com.ruoyi.system.domain.Gldry;
import com.ruoyi.system.service.IGldryService;

/**
 * 隔离点人员Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@Service
public class GldryServiceImpl implements IGldryService 
{
    @Autowired
    private GldryMapper gldryMapper;

    /**
     * 查询隔离点人员
     * 
     * @param id 隔离点人员主键
     * @return 隔离点人员
     */
    @Override
    public Gldry selectGldryById(Long id)
    {
        return gldryMapper.selectGldryById(id);
    }

    /**
     * 查询隔离点人员列表
     * 
     * @param gldry 隔离点人员
     * @return 隔离点人员
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Gldry> selectGldryList(Gldry gldry)
    {
        return gldryMapper.selectGldryList(gldry);
    }

    /**
     * 新增隔离点人员
     * 
     * @param gldry 隔离点人员
     * @return 结果
     */
    @Override
    public int insertGldry(Gldry gldry)
    {
        gldry.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        gldry.setCreateTime(DateUtils.getNowDate());
        return gldryMapper.insertGldry(gldry);
    }

    /**
     * 修改隔离点人员
     * 
     * @param gldry 隔离点人员
     * @return 结果
     */
    @Override
    public int updateGldry(Gldry gldry)
    {
        gldry.setUpdateTime(DateUtils.getNowDate());
        return gldryMapper.updateGldry(gldry);
    }

    /**
     * 批量删除隔离点人员
     * 
     * @param ids 需要删除的隔离点人员主键
     * @return 结果
     */
    @Override
    public int deleteGldryByIds(Long[] ids)
    {
        return gldryMapper.deleteGldryByIds(ids);
    }

    /**
     * 删除隔离点人员信息
     * 
     * @param id 隔离点人员主键
     * @return 结果
     */
    @Override
    public int deleteGldryById(Long id)
    {
        return gldryMapper.deleteGldryById(id);
    }
}
