package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.system.mapper.YxryMapper;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.service.IYxryService;

/**
 * 阳性人员Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@Service
public class YxryServiceImpl implements IYxryService 
{
    @Autowired
    private YxryMapper yxryMapper;

    /**
     * 查询阳性人员
     * 
     * @param id 阳性人员主键
     * @return 阳性人员
     */
    @Override
    public Yxry selectYxryById(Long id)
    {
        return yxryMapper.selectYxryById(id);
    }

    /**
     * 查询阳性人员列表
     * 
     * @param yxry 阳性人员
     * @return 阳性人员
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Yxry> selectYxryList(Yxry yxry)
    {
        return yxryMapper.selectYxryList(yxry);
    }

    /**
     * 新增阳性人员
     * 
     * @param yxry 阳性人员
     * @return 结果
     */
    @Override
    public int insertYxry(Yxry yxry)
    {
        yxry.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        yxry.setCreateTime(DateUtils.getNowDate());
        return yxryMapper.insertYxry(yxry);
    }

    /**
     * 修改阳性人员
     * 
     * @param yxry 阳性人员
     * @return 结果
     */
    @Override
    public int updateYxry(Yxry yxry)
    {
        yxry.setUpdateTime(DateUtils.getNowDate());
        return yxryMapper.updateYxry(yxry);
    }

    /**
     * 批量删除阳性人员
     * 
     * @param ids 需要删除的阳性人员主键
     * @return 结果
     */
    @Override
    public int deleteYxryByIds(Long[] ids)
    {
        return yxryMapper.deleteYxryByIds(ids);
    }

    /**
     * 删除阳性人员信息
     * 
     * @param id 阳性人员主键
     * @return 结果
     */
    @Override
    public int deleteYxryById(Long id)
    {
        return yxryMapper.deleteYxryById(id);
    }
}
